@@ -25,6 +25,7 @@
  */
 
 #include "internal.h"
+#include "mhd_str.h"
 
 #ifdef HAVE_MESSAGES
 #if DEBUG_STATES
@@ -133,32 +134,21 @@ MHD_http_unescape (char *val)
 {
   char *rpos = val;
   char *wpos = val;
-  char *end;
-  unsigned int num;
-  char buf3[3];
 
   while ('\0' != *rpos)
     {
+      uint32_t num;
       switch (*rpos)
 	{
 	case '%':
-          if ( ('\0' == rpos[1]) ||
-               ('\0' == rpos[2]) )
-          {
-            *wpos = '\0';
-            return wpos - val;
-          }
-	  buf3[0] = rpos[1];
-	  buf3[1] = rpos[2];
-	  buf3[2] = '\0';
-	  num = strtoul (buf3, &end, 16);
-	  if ('\0' == *end)
+          if (2 == MHD_strx_to_uint32_n_ (rpos + 1, 2, &num))
 	    {
 	      *wpos = (char)((unsigned char) num);
 	      wpos++;
 	      rpos += 3;
 	      break;
 	    }
+          /* TODO: add bad sequence handling */
 	  /* intentional fall through! */
 	default:
 	  *wpos = *rpos;
@@ -181,8 +171,8 @@ MHD_http_unescape (char *val)
  *        clobbered in the process!
  * @param cb function to call on each key-value pair found
  * @param[out] num_headers set to the number of headers found
- * @return #MHD_NO on failure (@a cb returned #MHD_NO), 
- *         #MHD_YES for success (parsing succeeded, @a cb always 
+ * @return #MHD_NO on failure (@a cb returned #MHD_NO),
+ *         #MHD_YES for success (parsing succeeded, @a cb always
  *                               returned #MHD_YES)
  */
 int
@@ -231,7 +221,7 @@ MHD_parse_arguments_ (struct MHD_Connection *connection,
 	  daemon->unescape_callback (daemon->unescape_callback_cls,
 				     connection,
 				     equals);
-	  if (MHD_YES != cb (connection, 
+	  if (MHD_YES != cb (connection,
 			     args,
 			     equals,
 			     kind))
@@ -274,7 +264,7 @@ MHD_parse_arguments_ (struct MHD_Connection *connection,
 				 equals);
       if (MHD_YES != cb (connection,
 			 args,
-			 equals, 
+			 equals,
 			 kind))
         return MHD_NO;
       (*num_headers)++;
