@@ -223,8 +223,8 @@ main (int argc, char *const *argv)
       fprintf (stderr, "Error: %s\n", strerror (errno));
       return -1;
     }
-#if EPOLL_SUPPORT
-  if (0 != (errorCount = testExternalGet (MHD_USE_EPOLL_LINUX_ONLY)))
+#ifdef EPOLL_SUPPORT
+  if (0 != (errorCount = testExternalGet (MHD_USE_EPOLL)))
     fprintf (stderr, "Fail: %d\n", errorCount);
 #endif
   if (0 != (errorCount = testExternalGet (0)))
